#!/bin/sh

# uvspec tools directory
tools="../../tools/"

# number of intervals in the final data 
intervals=15

# filter functions usually drop rapidly to the left and right and can 
# be neglected below some limit; determine left and right limits 
# so that the loss is smaller than $accur
accur=0.001

# extraterrestrial spectrum
extra=../../data/solar_flux/kurudz_0.1nm.dat

# space-separated list of filter functions
filter="ch006 ch008 ch016 ch039"

# wavelength unit in the filter function, nm or micron
filter_unit=micron


#########################################
# don't change anything below this line #
#########################################

for flt in $filter; do

  echo ... working on filter function $flt

  if `test $filter_unit = "micron"`; then
    echo ... converting $flt to nm
    gawk '!/#/{print $1*1000,$2+0}' $flt > $flt.nm
  fi

  if `test $filter_unit = "nm"`; then
    echo ... filter function $flt defined in nm, fine
    gawk '!/#/{print $1,$2+0}' $flt > $flt.nm
  fi

  echo ... interpolating $flt to $extra
  $tools/spline -q -l -x $extra $flt.nm | gawk '!/nan/' > $flt.spl

  echo ... combining interpolated $flt and $extra
  gawk 'FNR==NR{filter[$1+0]=$2};FNR<NR&&filter[$1+0]>0{print $1,$2,filter[$1+0],$2*filter[$1+0]}' $flt.spl $extra > $flt.ext

  echo ... integrating weighted irradiance
  gawk 'BEGIN{counter=1;sum[1]=0};FNR>1{++counter;sum[counter]=sum[counter-1]+0.5*($2*$3+y)*($1-x);};{wvl[counter]=$1;x=$1;y=$2*$3};END{for (i=1;i<=counter;i++) printf("%s %.8e\n", wvl[i],sum[i]/sum[counter])}' $flt.ext > $flt.int

  echo ... determining lower and upper limits to reach accuracy $accur
  lower=`gawk 'BEGIN{accur='$accur'/2};{wvl[FNR]=$1};$2<accur{lower=FNR};END{print wvl[lower]}' $flt.int`
  upper=`gawk 'BEGIN{accur='$accur'/2};{wvl[FNR]=$1};$2<1-accur{upper=FNR};END{upper++;print wvl[upper]}' $flt.int`

  echo ... selected wavelength range $lower nm to $upper nm

  gawk 'BEGIN{lower='$lower';upper='$upper';n='$intervals';step=(upper-lower)/n;for(i=0;i<n;i++) {print "'$tools'/integrate -q -l -a"lower+i*step" -b"lower+(i+1)*step" '$flt.ext'";print lower+(i+0.5)*step>"filter.x"}}' > tmp00001.sh

  echo ... creating output file $flt.extra
  sh tmp00001.sh | gawk 'BEGIN{while ((getline < "filter.x") > 0) wvl[++counter]=$1};{print wvl[FNR],$3}' > $flt.extra

  echo ... creating bands file $flt.wvl
  gawk 'BEGIN{lower='$lower';upper='$upper';n='$intervals';step=(upper-lower)/n;for(i=0;i<n;i++) printf("%.6g %.12g %.12g\n", (lower+(i+0.5)*step)/1000.0, (lower+i*step)/1000.0, (lower+(i+1)*step)/1000.0)}' | sort -g > $flt.wvl

  rm -f $flt.ext $flt.int $flt.nm $flt.spl $flt.tmp $flt.x tmp00001.sh filter.x
  
  echo
done

